/*
  This file is part of SLD.
  Copyright (C) 2008 Sebastien LUTTRINGER <contact@seblu.net>

  SLD is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; version 2 of the License.

  SLD is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with SLD; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include <unistd.h>
#include <iostream>
#include "error.h"
#include "log.hh"


Logger logout(std::cout);
Logger logerr(std::cerr);

Logger::Logger(std::ostream &o, const string &file) : flux_(o) {
  this->file(file);
}

Logger::~Logger() {
  if (logfile_ != 0)
    logfile_.close();
}

bool Logger::file(const string &filename) {
  // close previous logfile
  if (logfile_.is_open())
    logfile_.close();

  // open
  logfile_.open(filename.c_str(), std::fstream::app);
  return logfile_.is_open();
}

bool Logger::has_file() const {
  return logfile_.is_open();
}

Logger &operator<<(Logger &l, const string &s) {
  l.flux_ << s;
  if (l.has_file()) {
    l.logfile_ << s;
    l.logfile_.flush();
  }
  return l;
}

Logger &operator<<(Logger &l, const char *s) {
  l.flux_ << s;
  if (l.has_file()) {
    l.logfile_ << s;
    l.logfile_.flush();
  }
  return l;
}

Logger &operator<<(Logger &l, int i) {
  l.flux_ << i;
  if (l.has_file()) {
    l.logfile_ << i;
    l.logfile_.flush();
  }
  return l;
}
